@@ -5,16 +5,14 @@
 #' @importFrom sp coordinates
 #' @importFrom graphics points
 #' @examples \dontrun{
-#' map_lake_wiki(get_lake_wiki("Corey Lake"), "usa")
+#' map_lake_wiki(lake_wiki("Corey Lake"), database = "usa")
 #'
-#' map_lake_wiki(get_lake_wiki("Lake Nipigon"), regions = "Canada")
+#' map_lake_wiki(lake_wiki("Lake Nipigon"), regions = "Canada")
 #' }
 map_lake_wiki <- function(res, ...){
-
-  coords <- as.numeric(strsplit(res[which(res[,1] == "Coordinates"), 2],
-                                ",")[[1]])
-  res <- data.frame(matrix(rev(coords), ncol = 2))
-  sp::coordinates(res) <- ~X1 + X2
+  coords <- res[,c("Lon", "Lat")]
+  res <- data.frame(as.matrix(coords))
+  sp::coordinates(res) <- ~Lon + Lat
 
   maps::map(...)
   points(res, col = "red", cex = 1.5, pch = 19)
